@@ -45,7 +45,7 @@ class HeaderToLabelMiddleware(object):
         return int(round(time.time() * 1000))
 
     def __is_debug(self):
-        return logger.level.lower() != "info"
+        return logger.level != logging.INFO
 
     def _get_header(self, request, header_name):
         return request.META.get(header_name, DEFAULT_HEADER_VALUE)
